Unipag.py - Unipag Client for Python
====================================

Installation
------------

Install using pip (recommended): ::

    $ pip install unipag

or using easy_install: ::

    $ easy_install unipag

Report bugs
-----------

#. Report issues to the project's `Issues Tracking`_ on Github.

.. _`Issues Tracking`: http://github.com/ivelum/unipag.py/issues
